What’s new — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »

# What’s new

## Trunk

> - Implementation of the new actions proposal (Actions)
> - Delayed creation of widgets on tabs to improve performance for screens with lots of fields
> - Move to migrate 7.1

## Release 11.09.10

> - Refresh reexecutes queries in the table view

> - Deleted entities are grayed out in the GUI if they are deleted when visible

> - Add setup.py to new projects for easy packaging

> - The settings mechanism becomes plugable

> - Print preview does pdf export when no printer is available

> - Wizard to create a new project

> - API documentation integrated with sphinx

> - `camelot.core.exception.UserException`, a subclass of Exception that can be used to inform the user in a gentle way he should behave different.

> - Reduced memory usage

> - Experimental PySide support

> - Table views are sorted by primary key to avoid row flicker

> - German, French and Dutch translations

> - Generation of .po files integrated with setuptools

> - Fixes of VirtualAddress editor

> - example renamed to camelot_example to resolve naming conflicts with other projects

## Release 11.05.13

> - Faster opening of forms

> - ‘Home’ tab with application actions

> - add legend function to chart container

> - Workspace maximizes when double clicking on tab bar

> - Fix tab behavour of some editors

> - Support for editing columns in the frozen part of a table view

> - New DateTime Editor

> - More intuitive Code editor

> - More intuitive navigation pane

> - progress dialog when records are deleted

> - FileEditor supports removing files after copying them

> - EntityAdmin changes

>   - supports objects mapped with plain SQLAlchemy, documentation on how to use this
>   - confirm_delete reworked to delete_mode
>   - expanded_list_search option to tune which fields show up

> - ApplicationAdmin changes

>   - actions_changed_signal

>   - application actions show up in desktop workspace

> - postgres support for backup / restore

> - new actions : DocxApplicationAction, PixmapFormAction

> - Most editors now support background_color, editable and tooltip as dynamic attributes

## Release 10.11.27

> - Tab based desktop

> - Faster table view

> - Improved search queries

> - Much more dynamic field attributes : tooltip, background_color, editable, choices, prefix, suffix, arrow

> - Document merge wizard

> - Support for SQLAlchemy 0.6.x

> - Charts and matplotlib integration

> - Move from PyExcelerator to xlwt and xlrd

> - Move to new style signal/slot connections

> - Support for frozen columns in a table view

> - Faster backup and restore

## Release 10.07.02

> - Expanded search and filter options

> - Search works for integer, date and float fields

> - Sorting in table views and OneToMany widgets

> - Importer forces validation before importing

> - User translatable labels on forms

> - Litebox image preview for image fields

> - New editors and delegates :

>   - NoteDelegate

>   - LabelDelegate

>   - TextBoolDelegate

> - i18n improvements

> - Fix date editor on windows

> - Add a default model to store batch job information

> - Backup and restore available from the File menu

> - More documentation

## Release 09.12.07

> - Sqlalchemy 5.6 compatible

> - Dynamic background colors and tooltips

> - Generic import wizard

> - The busy indicator in the status bar

> - Support for lazy translations

> - Remove PIL dependency and only depend on QImage

> - Support multiple levels of class inheritance in the model

> - Various bugfixes, usability and speed improvements

> - Code cleanup

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »

Comments
blog comments powered by Disqus